@@ -1,8 +1,8 @@
-// Author: David Alexander
-
 #ifndef PBCOPPER_ALIGN_ALIGNCONFIG_H
 #define PBCOPPER_ALIGN_ALIGNCONFIG_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <cstdint>
 
 namespace PacBio {
