@@ -1,19 +1,18 @@
-// Authors: Lance Hepler, Brett Bowman
-
 #ifndef PBCOPPER_ALIGN_CHAINSEEDS_H
 #define PBCOPPER_ALIGN_CHAINSEEDS_H
 
+#include <pbcopper/PbcopperConfig.h>
+
+#include <pbcopper/align/ChainSeedsConfig.h>
+#include <pbcopper/align/Seeds.h>
+
 #include <map>
+#include <optional>
 #include <queue>
 #include <set>
 #include <utility>
 #include <vector>
 
-#include <boost/optional.hpp>
-
-#include <pbcopper/align/ChainSeedsConfig.h>
-#include <pbcopper/align/Seeds.h>
-
 namespace PacBio {
 namespace Align {
 
@@ -89,7 +88,7 @@ struct SDPHit : public Seed
 {
     size_t Index;
 
-    SDPHit(const Seed& seed, const size_t index);
+    SDPHit(const Seed& seed, size_t index);
     bool operator<(const SDPHit& other) const noexcept;
 };
 
@@ -113,10 +112,10 @@ bool IndexCompare(const SDPHit& lhs, const SDPHit& rhs);
 ///
 struct SDPColumn
 {
-    boost::optional<SDPHit> Seed;
+    std::optional<SDPHit> Seed;
     size_t Column;
 
-    SDPColumn(size_t column, const boost::optional<SDPHit> seed = boost::none);
+    SDPColumn(size_t column, std::optional<SDPHit> seed = std::nullopt);
     bool operator<(const SDPColumn& other) const noexcept;
 };
 
@@ -128,8 +127,8 @@ struct SDPColumn
 ///
 /// \return  vector<optional<SDPHits>>  For each seed in the input vector, the
 ///             first index that is visible to it's left, if any.
-std::vector<boost::optional<SDPHit>> ComputeVisibilityLeft(const std::vector<SDPHit>& seeds,
-                                                           std::set<SDPHit>& sweepSet);
+std::vector<std::optional<SDPHit>> ComputeVisibilityLeft(const std::vector<SDPHit>& seeds,
+                                                         std::set<SDPHit>& sweepSet);
 
 ///
 /// A possible chain of SDP seeds.  A simple struct for wrapping the
@@ -195,8 +194,8 @@ void InitializeSeedsAndScores(const Seeds& seedSet, std::vector<SDPHit>* seeds,
 ///                   a lower diagonal than the 'downstream' seed.
 void __attribute__((__unused__))
 ChainSeedsImpl(std::priority_queue<ChainHit, std::vector<ChainHit>, ChainHitCompare>* chainHits,
-               std::vector<boost::optional<size_t>>* chainPred, std::vector<SDPHit>* seeds,
-               std::vector<long>& scores, const size_t seedSetIdx, const ChainSeedsConfig& config);
+               std::vector<std::optional<size_t>>* chainPred, std::vector<SDPHit>* seeds,
+               std::vector<long>& scores, size_t seedSetIdx, const ChainSeedsConfig& config);
 
 /// Search a Seed set for the best numCandidates sets of locally-chainable
 /// seeds according to some scoring criteria.  Seed chains are scored based
@@ -241,8 +240,8 @@ std::vector<Seeds> ChainedSeedSets(const Seeds& seedSet, const ChainSeedsConfig&
 ///
 /// \return  A vector of SeedSets containing locally chained seeds.
 ///
-std::vector<std::pair<size_t, Seeds>> ChainSeeds(const std::map<size_t, Seeds> seedSets,
-                                                 const ChainSeedsConfig config);
+std::vector<std::pair<size_t, Seeds>> ChainSeeds(std::map<size_t, Seeds> seedSets,
+                                                 ChainSeedsConfig config);
 
 }  // namespace Align
 }  // namespace PacBio
