@@ -1,16 +1,16 @@
-// Author: David Alexander
+#ifndef PBCOPPER_ALIGN_LINEARALIGNMENT_H
+#define PBCOPPER_ALIGN_LINEARALIGNMENT_H
 
 //
 // Linear-space basic alignment following Hirschberg
 //
 
-#ifndef PBCOPPER_ALIGN_LINEARALIGNMENT_H
-#define PBCOPPER_ALIGN_LINEARALIGNMENT_H
-
-#include <string>
+#include <pbcopper/PbcopperConfig.h>
 
 #include <pbcopper/align/PairwiseAlignment.h>
 
+#include <string>
+
 namespace PacBio {
 namespace Align {
 
