@@ -1,20 +1,19 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_CLI_v2_MULTITOOLINTERFACEDATA_H
 #define PBCOPPER_CLI_v2_MULTITOOLINTERFACEDATA_H
 
 #include <pbcopper/PbcopperConfig.h>
 
-#include <memory>
-#include <string>
-
-#include <boost/optional.hpp>
-
 #include <pbcopper/cli2/Tool.h>
+#include <pbcopper/cli2/VersionPrinterCallback.h>
 #include <pbcopper/cli2/internal/InterfaceData.h>
 #include <pbcopper/cli2/internal/OptionData.h>
+#include <pbcopper/cli2/internal/VersionPrinter.h>
 #include <pbcopper/logging/LogConfig.h>
 
+#include <memory>
+#include <optional>
+#include <string>
+
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
@@ -25,13 +24,16 @@ namespace internal {
 struct MultiToolInterfaceData
 {
     MultiToolInterfaceData(std::string appName, std::string appDescription, std::string appVersion,
-                           OptionData help, OptionData versionOption)
+                           OptionData help, OptionData versionOption, OptionData showAllHelpOption)
         : appName_{std::move(appName)}
         , appDescription_{std::move(appDescription)}
         , appVersion_{std::move(appVersion)}
-        , helpOption_(std::move(help))              // icc 17 hack
-        , versionOption_(std::move(versionOption))  // icc 17 hack
+        , helpOption_(std::move(help))                      // icc 17 hack
+        , versionOption_(std::move(versionOption))          // icc 17 hack
+        , showAllHelpOption_(std::move(showAllHelpOption))  // icc 17 hack
     {
+        // default version printer
+        versionPrinter_ = [](const MultiToolInterface& i) { internal::VersionPrinter::Print(i); };
     }
 
     std::string appName_;
@@ -41,10 +43,13 @@ struct MultiToolInterfaceData
 
     OptionData helpOption_;
     OptionData versionOption_;
+    OptionData showAllHelpOption_;
 
     std::vector<Tool> tools_;
 
-    boost::optional<Logging::LogConfig> logConfig_;
+    std::optional<Logging::LogConfig> logConfig_;
+
+    MultiToolVersionPrinterCallback versionPrinter_;
 };
 
 }  // namespace internal
