@@ -1,18 +1,15 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_CLI_v2_OPTIONDATA_H
 #define PBCOPPER_CLI_v2_OPTIONDATA_H
 
 #include <pbcopper/PbcopperConfig.h>
 
+#include <pbcopper/cli2/OptionValue.h>
+
 #include <algorithm>
+#include <optional>
 #include <string>
 #include <vector>
 
-#include <boost/optional.hpp>
-
-#include <pbcopper/cli2/OptionValue.h>
-
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
@@ -27,9 +24,10 @@ struct OptionData
     std::string description;
 
     OptionValueType type = OptionValueType::BOOL;
-    boost::optional<OptionValue> defaultValue;
+    std::optional<OptionValue> defaultValue;
 
     bool isHidden = false;
+    bool isDefaultValueHidden = false;
 
     std::vector<OptionValue> choices;
     bool isChoicesHidden = false;
