@@ -1,17 +1,14 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_CLI_v2_POSITONALARGUMENTDATA_H
 #define PBCOPPER_CLI_v2_POSITONALARGUMENTDATA_H
 
 #include <pbcopper/PbcopperConfig.h>
 
+#include <pbcopper/cli2/OptionValue.h>
+
+#include <optional>
 #include <string>
 #include <vector>
 
-#include <boost/optional.hpp>
-
-#include <pbcopper/cli2/OptionValue.h>
-
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
