@@ -1,13 +1,13 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_DATA_CIGAROPERATION_H
 #define PBCOPPER_DATA_CIGAROPERATION_H
 
 #include <pbcopper/PbcopperConfig.h>
 
-#include <cstdint>
 #include <stdexcept>
 
+#include <cassert>
+#include <cstdint>
+
 namespace PacBio {
 namespace Data {
 
@@ -52,13 +52,37 @@ public:
     ///
     /// \param[in] type CigarOperationType value
     /// \returns SAM/BAM character code
-    static char TypeToChar(const CigarOperationType type);
+    static char TypeToChar(CigarOperationType type);
 
     /// Convert between CigarOperationType enum & SAM/BAM character code.
     ///
     /// \param[in] c SAM/BAM character code
     /// \returns CigarOperationType value
-    static CigarOperationType CharToType(const char c);
+    PB_CUDA_HOST PB_CUDA_DEVICE static CigarOperationType CharToType(const char c)
+    {
+        switch (c) {
+            case 'S':
+                return CigarOperationType::SOFT_CLIP;
+            case '=':
+                return CigarOperationType::SEQUENCE_MATCH;
+            case 'X':
+                return CigarOperationType::SEQUENCE_MISMATCH;
+            case 'I':
+                return CigarOperationType::INSERTION;
+            case 'D':
+                return CigarOperationType::DELETION;
+            case 'N':
+                return CigarOperationType::REFERENCE_SKIP;
+            case 'H':
+                return CigarOperationType::HARD_CLIP;
+            case 'P':
+                return CigarOperationType::PADDING;
+            case 'M':
+                return CigarOperationType::ALIGNMENT_MATCH;
+            default:
+                return CigarOperationType::UNKNOWN_OP;
+        }
+    }
 
     /// \}
 
@@ -67,8 +91,24 @@ public:
     /// \{
 
     CigarOperation() = default;
-    CigarOperation(char c, uint32_t length);
-    CigarOperation(CigarOperationType op, uint32_t length);
+
+    PB_CUDA_HOST PB_CUDA_DEVICE CigarOperation(char c, uint32_t length)
+        : CigarOperation{CigarOperation::CharToType(c), length}
+    {
+    }
+
+    PB_CUDA_HOST PB_CUDA_DEVICE CigarOperation(CigarOperationType op, uint32_t length)
+        : type_{op}, length_{length}
+    {
+#ifndef __CUDA_ARCH__  // host
+        if (AutoValidateCigar && (type_ == CigarOperationType::ALIGNMENT_MATCH)) {
+            throw std::runtime_error{
+                "[pbcopper] CIGAR operation ERROR: 'M' is not allowed in PacBio BAM files. Use "
+                "'X/=' "
+                "instead."};
+        }
+#endif
+    }
 
     /// \}
 
@@ -77,10 +117,10 @@ public:
     char Char() const;
 
     /// \returns operation length
-    uint32_t Length() const;
+    PB_CUDA_HOST PB_CUDA_DEVICE uint32_t Length() const { return length_; }
 
     /// \returns operation type as CigarOperationType enum value
-    CigarOperationType Type() const;
+    PB_CUDA_HOST PB_CUDA_DEVICE CigarOperationType Type() const { return type_; }
 
     /// \}
 
@@ -92,19 +132,19 @@ public:
     ///
     /// \param[in] opChar SAM/BAM character code
     /// \returns reference to this operation
-    CigarOperation& Char(const char opChar);
+    CigarOperation& Char(char opChar);
 
     /// Sets this operation length.
     ///
     /// \param[in] length
     /// \returns reference to this operation
-    CigarOperation& Length(const uint32_t length);
+    CigarOperation& Length(uint32_t length);
 
     /// Sets this operation type.
     ///
     /// \param[in] opType CigarOperationType value
     /// \returns reference to this operation
-    CigarOperation& Type(const CigarOperationType opType);
+    CigarOperation& Type(CigarOperationType opType);
 
     /// \}
 
@@ -120,14 +160,17 @@ public:
 
     /// \}
 
+private:
+    static bool AutoValidateCigar;
+
 private:
     CigarOperationType type_ = CigarOperationType::UNKNOWN_OP;
     uint32_t length_ = 0;
 };
 
-bool ConsumesQuery(const CigarOperationType type);
+bool ConsumesQuery(CigarOperationType type);
 
-bool ConsumesReference(const CigarOperationType type);
+bool ConsumesReference(CigarOperationType type);
 
 }  // namespace Data
 }  // namespace PacBio
