@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_DATA_GENOMICINTERVAL_H
 #define PBCOPPER_DATA_GENOMICINTERVAL_H
 
@@ -8,9 +6,10 @@
 #include <pbcopper/data/Interval.h>
 #include <pbcopper/data/Position.h>
 
-#include <cstddef>
 #include <string>
 
+#include <cstddef>
+
 namespace PacBio {
 namespace Data {
 
@@ -120,14 +119,14 @@ public:
     /// \param[in] start
     /// \returns reference to this interval
     ///
-    GenomicInterval& Start(const Position start);
+    GenomicInterval& Start(Position start);
 
     /// Sets this interval's stop coordinate.
     ///
     /// \param[in] stop
     /// \returns reference to this interval
     ///
-    GenomicInterval& Stop(const Position stop);
+    GenomicInterval& Stop(Position stop);
 
     /// \}
 
