@@ -1,5 +1,3 @@
-// Author: Lance Hepler, Derek Barnett
-
 #ifndef PBCOPPER_DATA_SNR_H
 #define PBCOPPER_DATA_SNR_H
 
@@ -28,8 +26,8 @@ struct SNR
 
     operator std::vector<float>() const;
 
-    const float& operator[](const int i) const noexcept;
-    float& operator[](const int i) noexcept;
+    const float& operator[](int i) const noexcept;
+    float& operator[](int i) noexcept;
 
     bool operator==(const SNR& other) const noexcept;
     bool operator!=(const SNR& other) const noexcept;
