@@ -1,10 +1,10 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_DATA_STRAND_H
 #define PBCOPPER_DATA_STRAND_H
 
 #include <pbcopper/PbcopperConfig.h>
 
+#include <iosfwd>
+
 #include <cstdint>
 
 namespace PacBio {
@@ -20,6 +20,8 @@ enum class Strand : uint8_t
     UNMAPPED,
 };
 
+std::ostream& operator<<(std::ostream& os, const Strand& strand);
+
 }  // namespace Data
 }  // namespace PacBio
 
