@@ -1,20 +1,20 @@
-// Author: Lance Hepler, Derek Barnett
-
 #ifndef PBCOPPER_LOGGING_LOGCONFIG_H
 #define PBCOPPER_LOGGING_LOGCONFIG_H
 
-#include <string>
+#include <pbcopper/PbcopperConfig.h>
 
 #include <pbcopper/logging/LogField.h>
 #include <pbcopper/logging/LogLevel.h>
 
+#include <string>
+
 namespace PacBio {
 namespace Logging {
 
 struct LogConfig
 {
     LogConfig();
-    explicit LogConfig(const LogLevel level);
+    explicit LogConfig(LogLevel level);
 
     LogLevel Level;
     std::string Header;
