@@ -1,8 +1,8 @@
-// Author: Lance Hepler, Derek Barnett
-
 #ifndef PBCOPPER_LOGGING_LOGLEVEL_H
 #define PBCOPPER_LOGGING_LOGLEVEL_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <string>
 
 namespace PacBio {
@@ -27,7 +27,7 @@ public:
     };
 
 public:
-    LogLevel(const int value);
+    LogLevel(int value);
     LogLevel(const std::string& value);
 
 public:
