@@ -1,14 +1,14 @@
-// Author: Lance Hepler, Derek Barnett
-
 #ifndef PBCOPPER_LOGGING_LOGMESSAGE_H
 #define PBCOPPER_LOGGING_LOGMESSAGE_H
 
+#include <pbcopper/PbcopperConfig.h>
+
+#include <pbcopper/logging/LogLevel.h>
+
 #include <memory>
 #include <sstream>
 #include <utility>
 
-#include <pbcopper/logging/LogLevel.h>
-
 namespace PacBio {
 namespace Logging {
 
@@ -19,7 +19,7 @@ using LogLevelStream = std::pair<LogLevel, std::ostringstream>;
 class LogMessage
 {
 public:
-    LogMessage(const char* file, const char* function, unsigned int line, const LogLevel level,
+    LogMessage(const char* file, const char* function, unsigned int line, LogLevel level,
                Logger& logger);
     ~LogMessage();
 
@@ -27,7 +27,9 @@ public:
     template <typename T>
     LogMessage& operator<<(const T& t)
     {
-        if (ptr_) ptr_->second << t;
+        if (ptr_) {
+            ptr_->second << t;
+        }
         return *this;
     }
 
