@@ -1,10 +1,12 @@
-// Author: Lance Hepler, Derek Barnett
-
 #ifndef PBCOPPER_LOGGING_LOGGING_H
 #define PBCOPPER_LOGGING_LOGGING_H
 
 #include <pbcopper/PbcopperConfig.h>
 
+#include <pbcopper/logging/LogConfig.h>
+#include <pbcopper/logging/LogLevel.h>
+#include <pbcopper/logging/LogMessage.h>
+
 #include <condition_variable>
 #include <fstream>
 #include <memory>
@@ -14,10 +16,6 @@
 #include <string>
 #include <thread>
 
-#include <pbcopper/logging/LogConfig.h>
-#include <pbcopper/logging/LogLevel.h>
-#include <pbcopper/logging/LogMessage.h>
-
 namespace PacBio {
 namespace Logging {
 
@@ -36,8 +34,8 @@ public:
     ///
     static Logger& Default(Logger* logger = nullptr);
 
-    Logger(std::ostream& out, const LogLevel level);
-    Logger(const std::string& filename, const LogLevel level);
+    Logger(std::ostream& out, LogLevel level);
+    Logger(const std::string& filename, LogLevel level);
 
     Logger(std::ostream& out, const LogConfig& config);
     Logger(const std::string& filename, const LogConfig& config);
@@ -46,6 +44,8 @@ public:
     Logger& operator=(const Logger&) = delete;
     ~Logger();
 
+    LogLevel Level() const;
+
 private:
     // output control
     std::ofstream logFile_;
@@ -62,10 +62,12 @@ private:
     friend class LogMessage;
 
     Logger& operator<<(std::unique_ptr<LogLevelStream>&& ptr);
-    bool Handles(const LogLevel level) const;
+    bool Handles(LogLevel level) const;
     void MessageWriter();
 };
 
+LogLevel CurrentLogLevel();
+
 #define PBLOGGER_LEVEL(lg, lvl) \
     PacBio::Logging::LogMessage(__FILE__, __func__, __LINE__, PacBio::Logging::lvl, (lg))
 
