@@ -1,5 +1,3 @@
-// Author: Lance Hepler & Armin Töpfer
-
 #ifndef PBCOPPER_PARALLEL_FIREANDFORGET_H
 #define PBCOPPER_PARALLEL_FIREANDFORGET_H
 
@@ -7,13 +5,16 @@
 
 #include <atomic>
 #include <condition_variable>
-#include <cstddef>
 #include <exception>
+#include <functional>
 #include <future>
 #include <mutex>
+#include <optional>
 #include <queue>
+#include <stdexcept>
 
-#include <boost/optional.hpp>
+#include <cstddef>
+#include <cstdint>
 
 namespace PacBio {
 namespace Parallel {
@@ -21,11 +22,16 @@ namespace Parallel {
 class FireAndForget
 {
 private:
-    typedef boost::optional<std::packaged_task<void()>> TTask;
+    typedef std::optional<std::packaged_task<void()>> TTask;
 
 public:
     FireAndForget(const size_t size, const size_t mul = 2)
-        : exc{nullptr}, sz{size * mul}, abort{false}, thrown{false}
+        : exc{nullptr}
+        , numThreads{size}
+        , sz{size * mul}
+        , abort{false}
+        , thrown{false}
+        , acceptingJobs{true}
     {
         for (size_t i = 0; i < size; ++i) {
             threads.emplace_back(std::thread([this]() {
@@ -56,12 +62,19 @@ public:
 
     ~FireAndForget() noexcept(false)
     {
-        if (exc && !thrown) std::rethrow_exception(exc);
+        if (exc && !thrown) {
+            std::rethrow_exception(exc);
+        }
     }
 
     template <typename F, typename... Args>
     void ProduceWith(F&& f, Args&&... args)
     {
+        if (!acceptingJobs) {
+            throw std::runtime_error(
+                "FireAndForget error: Cannot dispatch jobs to finalized thread pool!");
+        }
+
         std::packaged_task<void()> task{std::bind(std::forward<F>(f), std::forward<Args>(args)...)};
 
         {
@@ -72,7 +85,9 @@ public:
             }
 
             popped.wait(lk, [&task, this]() {
-                if (exc) std::rethrow_exception(exc);
+                if (exc) {
+                    std::rethrow_exception(exc);
+                }
 
                 if (head.size() < sz) {
                     head.emplace(std::move(task));
@@ -87,18 +102,20 @@ public:
 
     void Finalize()
     {
+        acceptingJobs = false;
         {
             std::lock_guard<std::mutex> g(m);
-            // Push boost::none to signal that there are no further tasks
-            head.emplace(boost::none);
+            // Push sentinel to signal that there are no further tasks
+            head.emplace();
         }
         // Let all workers know that they should look that there is no further work
         pushed.notify_all();
 
         // Wait for all threads to join and do not continue before all tasks
         // have been finished.
-        for (auto& thread : threads)
+        for (auto& thread : threads) {
             thread.join();
+        }
 
         // Is there a final exception, throw if so..
         if (exc) {
@@ -107,15 +124,19 @@ public:
         }
     }
 
+    size_t NumThreads() const { return numThreads; }
+
 private:
     TTask PopTask()
     {
-        TTask task(boost::none);
+        TTask task;
 
         {
             std::unique_lock<std::mutex> lk(m);
             pushed.wait(lk, [&task, this]() {
-                if (head.empty()) return false;
+                if (head.empty()) {
+                    return false;
+                }
 
                 if ((task = std::move(head.front()))) {
                     head.pop();
@@ -135,11 +156,24 @@ private:
     std::condition_variable pushed;
     std::exception_ptr exc;
     std::mutex m;
+    size_t numThreads;
     size_t sz;
     std::atomic_bool abort;
     std::atomic_bool thrown;
+    std::atomic_bool acceptingJobs;
 };
 
+///
+/// \brief Use an existing FireAndForget to dispatch [0, numEntries) callbacks.
+///        Returns after all dispatched jobs finished.
+///
+/// \param faf         reference to FaF, nullptr allowed
+/// \param numEntries  number of submissions
+/// \param callback    function to be dispatched to FaF
+///
+void Dispatch(Parallel::FireAndForget* faf, int32_t numEntries,
+              const std::function<void(int32_t)>& callback);
+
 }  // namespace Parallel
 }  // namespace PacBio
 
