@@ -1,15 +1,13 @@
-// Authors: Chris Dunn, Zev Kronenberg, Derek Barnett
-
 #ifndef PBCOPPER_PBMER_DNABIT_H
 #define PBCOPPER_PBMER_DNABIT_H
 
 #include <pbcopper/PbcopperConfig.h>
 
-#include <cstdint>
-
 #include <string>
 #include <vector>
 
+#include <cstdint>
+
 namespace PacBio {
 namespace Pbmer {
 
@@ -27,6 +25,7 @@ public:
     uint8_t msize = 0;
 
     DnaBit();
+
     DnaBit(uint64_t k, uint8_t strand, uint8_t size);
 
     // Ignores strand, compares hashed kmer.
@@ -39,6 +38,21 @@ public:
     bool operator==(DnaBit const& b) const noexcept;
     bool operator!=(DnaBit const& b) const noexcept;
 
+    ///
+    /// Sets a base at a given position
+    ///
+    void SetBase(char c, int position);
+
+    ///
+    /// Delete a base at a given position
+    ///
+    void DeleteBase(int position);
+
+    ///
+    /// Inserts a base at a given position
+    ///
+    void InsertBase(char c, int position);
+
     ///
     /// \return the hashed kmer
     ///
@@ -97,14 +111,14 @@ public:
     ///
     /// Put a base at the end of the kmer
     //
-    void AppendBase(const uint8_t c);
-    void AppendBase(const char c);
+    void AppendBase(uint8_t c);
+    void AppendBase(char c);
 
     ///
     /// Put a base at the beginning of kmer
     ///
-    void PrependBase(const uint8_t c);
-    void PrependBase(const char c);
+    void PrependBase(uint8_t c);
+    void PrependBase(char c);
 
     ///
     /// Get the first idx
@@ -139,10 +153,15 @@ public:
     /// Unpack top 80 bits into a DnaBit
     ///
     void Bin2DnaBit(BI bin);
+
+    ///
+    /// Return all kmers off by one base, includes the source kmer. NO indels.
+    ///
+    std::vector<DnaBit> Neighbors();
 };
 
 // This should remain a function, it has a lot of general utility.
-uint64_t ReverseComp64(const uint64_t mer, uint8_t kmerSize);
+uint64_t ReverseComp64(uint64_t mer, uint8_t kmerSize);
 // This should remain a function, it has a lot of general utility.
 uint64_t Mix64Masked(uint64_t key, uint8_t kmerSize) noexcept;
 
