@@ -1,15 +1,16 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_QGRAM_HASHING_INL_H
 #define PBCOPPER_QGRAM_HASHING_INL_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <array>
+#include <stdexcept>
+#include <string>
+
 #include <cassert>
 #include <cmath>
 #include <cstddef>
 #include <cstdint>
-#include <stdexcept>
-#include <string>
 
 namespace PacBio {
 namespace QGram {
@@ -33,9 +34,9 @@ inline uint8_t BaseCode(const char c)
 // recursive q-gram hash calculator
 inline uint64_t HashImpl(uint64_t hash, std::string::const_iterator iter, size_t q)
 {
-    if (q == 1)
+    if (q == 1) {
         return hash;
-    else {
+    } else {
         ++iter;
         return HashImpl(hash * ALPHABET_SIZE + BaseCode(*iter), iter, q - 1);
     }
@@ -70,10 +71,11 @@ public:
         // but want to still enforce this requirement here (in case of clients
         // 'sneaking' into internal implementation or, more likely, in case later
         // refactoring upstream removes the check).
-        if (seq.size() < q_)
+        if (seq.size() < q_) {
             throw std::invalid_argument{"[pbcopper] qgram ERROR: sequence size (" +
                                         std::to_string(seq.size()) + ") must be >= q (" +
                                         std::to_string(q_)};
+        }
 
         currentHash_ = HashImpl(BaseCode(*iter_), iter_, q_ - 1);
     }
