@@ -1,19 +1,17 @@
-// Author: Nat Echols, Derek Barnett
-
-// see pbcommand/schemas/pbreport.avsc
-
 #ifndef PBCOPPER_REPORTS_REPORT_H
 #define PBCOPPER_REPORTS_REPORT_H
 
+// see pbcommand/schemas/pbreport.avsc
+
 #include <pbcopper/PbcopperConfig.h>
 
-#include <cstddef>
+#include <boost/variant.hpp>
 
 #include <iosfwd>
 #include <string>
 #include <vector>
 
-#include <boost/variant.hpp>
+#include <cstddef>
 
 namespace PacBio {
 namespace Reports {
@@ -59,7 +57,7 @@ private:
 class Column : public BaseReportElement
 {
 public:
-    Column(std::string id_, std::vector<ReportValue> values, std::string header = "");
+    Column(std::string id, std::vector<ReportValue> values, std::string header = "");
 
     // header
     const std::string& Header() const;
