@@ -1,5 +1,3 @@
-// Authors: Brett Bowman, Derek Barnett
-
 #include <pbcopper/align/FindSeeds.h>
 
 #include <pbcopper/qgram/Index.h>
@@ -10,7 +8,7 @@ namespace PacBio {
 namespace Align {
 
 std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::string& seq,
-                                  const boost::optional<size_t> qIdx, const bool filterHomopolymers)
+                                  const std::optional<size_t> qIdx, const bool filterHomopolymers)
 {
     std::map<size_t, Seeds> seeds;
 
@@ -18,7 +16,9 @@ std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::
         const auto queryPos = hits.QueryPosition();
         for (const auto& hit : hits) {
             const auto rIdx = hit.Id();
-            if (qIdx && rIdx == *qIdx) continue;
+            if (qIdx && rIdx == *qIdx) {
+                continue;
+            }
 
             const auto seed = Seed{queryPos, hit.Position(), index.Size()};
             auto& rIdxSeeds = seeds[rIdx];
@@ -35,7 +35,7 @@ std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::
 }
 
 std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::string& seq,
-                                  const boost::optional<size_t> qIdx)
+                                  const std::optional<size_t> qIdx)
 {
     return FindSeeds(index, seq, qIdx, Default::FilterHomopolymers);
 }
@@ -43,18 +43,20 @@ std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::
 std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::string& seq,
                                   const bool filterHomopolymers)
 {
-    return FindSeeds(index, seq, boost::none, filterHomopolymers);
+    return FindSeeds(index, seq, std::nullopt, filterHomopolymers);
 }
 
 std::map<size_t, Seeds> FindSeeds(const PacBio::QGram::Index& index, const std::string& seq)
 {
-    return FindSeeds(index, seq, boost::none, Default::FilterHomopolymers);
+    return FindSeeds(index, seq, std::nullopt, Default::FilterHomopolymers);
 }
 
 Seeds FindSeeds(const size_t qGramSize, const std::string& seq1, const std::string& seq2,
                 const bool filterHomopolymers)
 {
-    if (seq2.length() < qGramSize) return Seeds{};
+    if (seq2.length() < qGramSize) {
+        return Seeds{};
+    }
     const auto index = PacBio::QGram::Index{qGramSize, seq2};
     const auto multiSeeds = FindSeeds(index, seq1, filterHomopolymers);
     return (multiSeeds.empty() ? Seeds{} : multiSeeds.cbegin()->second);
