@@ -1,11 +1,12 @@
 #include <pbcopper/cli2/internal/InterfaceHelpPrinter.h>
 
+#include <pbcopper/utility/StringUtils.h>
+#include "PbBoilerplateDisclaimer.h"
+
 #include <algorithm>
 #include <ostream>
 #include <sstream>
 
-#include <pbcopper/utility/StringUtils.h>
-
 using HelpMetrics = PacBio::CLI_v2::internal::HelpMetrics;
 using Option = PacBio::CLI_v2::Option;
 using OptionData = PacBio::CLI_v2::internal::OptionData;
@@ -18,21 +19,34 @@ namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
 
-InterfaceHelpPrinter::InterfaceHelpPrinter(Interface interface)
-    : metrics_{interface}, interface_{std::move(interface)}
+InterfaceHelpPrinter::InterfaceHelpPrinter(Interface interface, HiddenOptionMode hiddenOptionMode)
+    : metrics_{interface, hiddenOptionMode}
+    , interface_{std::move(interface)}
+    , showHiddenOptions_{hiddenOptionMode == HiddenOptionMode::SHOW}
 {
     MakeHelpText();
 }
 
-InterfaceHelpPrinter::InterfaceHelpPrinter(Interface interface, const size_t maxColumn)
-    : metrics_{interface, maxColumn}, interface_{std::move(interface)}
+InterfaceHelpPrinter::InterfaceHelpPrinter(Interface interface, const size_t maxColumn,
+                                           HiddenOptionMode hiddenOptionMode)
+    : metrics_{interface, maxColumn, hiddenOptionMode}
+    , interface_{std::move(interface)}
+    , showHiddenOptions_{hiddenOptionMode == HiddenOptionMode::SHOW}
 {
     MakeHelpText();
 }
 
 std::string InterfaceHelpPrinter::Choices(const OptionData& option)
 {
-    if (option.isHidden || option.choices.empty() || option.isChoicesHidden) return {};
+    // nothing to show
+    if (option.choices.empty()) {
+        return {};
+    }
+
+    // check for hidden status
+    if ((option.isHidden || option.isChoicesHidden) && !showHiddenOptions_) {
+        return {};
+    }
 
     std::ostringstream out;
     for (const auto& choice : option.choices) {
@@ -65,26 +79,28 @@ std::string InterfaceHelpPrinter::Choices(const OptionData& option)
 
 std::string InterfaceHelpPrinter::DefaultValue(const OptionData& option)
 {
-    if (!ShouldShowDefaultValue(option)) return {};
+    if (!ShouldShowDefaultValue(option)) {
+        return {};
+    }
 
     std::ostringstream out;
     switch (option.type) {
         case OptionValueType::INT:
-            out << OptionValueToInt(option.defaultValue.get());
+            out << OptionValueToInt(*option.defaultValue);
             break;
         case OptionValueType::UINT:
-            out << OptionValueToUInt(option.defaultValue.get());
+            out << OptionValueToUInt(*option.defaultValue);
             break;
         case OptionValueType::FLOAT:
-            out << OptionValueToDouble(option.defaultValue.get());
+            out << OptionValueToDouble(*option.defaultValue);
             break;
         case OptionValueType::STRING:
         case OptionValueType::FILE:
         case OptionValueType::DIR:
-            out << OptionValueToString(option.defaultValue.get());
+            out << OptionValueToString(*option.defaultValue);
             break;
         case OptionValueType::BOOL: {
-            const bool on = OptionValueToBool(option.defaultValue.get());
+            const bool on = OptionValueToBool(*option.defaultValue);
             out << (on ? "true" : "false");
             break;
         }
@@ -97,7 +113,9 @@ std::string InterfaceHelpPrinter::DefaultValue(const OptionData& option)
 std::string InterfaceHelpPrinter::Description()
 {
     const auto& description = interface_.ApplicationDescription();
-    if (description.empty()) return {};
+    if (description.empty()) {
+        return {};
+    }
 
     // maybe word-wrap description
     std::ostringstream out;
@@ -106,8 +124,9 @@ std::string InterfaceHelpPrinter::Description()
     const auto wrappedLines = Utility::WordWrappedLines(description, max);
     if (!wrappedLines.empty()) {
         out << wrappedLines.at(0);
-        for (size_t i = 1; i < wrappedLines.size(); ++i)
+        for (size_t i = 1; i < wrappedLines.size(); ++i) {
             out << '\n' << std::string(indent, ' ') << wrappedLines.at(i);
+        }
     }
     return out.str();
 }
@@ -118,18 +137,34 @@ void InterfaceHelpPrinter::MakeHelpText()
     result << interface_.ApplicationName();
 
     const std::string description = Description();
-    if (!description.empty()) result << " - " << Description();
+    if (!description.empty()) {
+        result << " - " << Description();
+    }
 
     result << '\n' << '\n' << Usage() << '\n';
 
     const std::string posArgs = PositionalArguments();
-    if (!posArgs.empty()) result << '\n' << posArgs;  // << '\n';
+    if (!posArgs.empty()) {
+        result << '\n' << posArgs;
+    }
 
     const std::string options = Options();
-    if (!options.empty()) result << '\n' << options << '\n';
+    if (!options.empty()) {
+        result << '\n' << options << '\n';
+    }
 
     const auto& footer = interface_.HelpFooter();
-    if (!footer.empty()) result << footer << '\n';
+    if (!footer.empty()) {
+        result << footer << '\n';
+
+        // Some application footers contain trailing newlines, some do not.
+        // Ensure we have at least one empty line between footer and disclaimer.
+        if (footer.back() != '\n') {
+            result << '\n';
+        }
+    }
+
+    result << PB_BOILERPLATE_DISCLAIMER;
 
     text_ = result.str();
 }
@@ -150,23 +185,33 @@ std::string InterfaceHelpPrinter::OptionDescription(const OptionData& option)
     out << option.description;
 
     const std::string choices = Choices(option);
-    if (!choices.empty()) out << " Valid choices: (" << choices << ").";
+    if (!choices.empty()) {
+        out << " Valid choices: (" << choices << ").";
+    }
 
     const auto defaultValue = DefaultValue(option);
-    if (!defaultValue.empty()) out << " [" << defaultValue << ']';
+    if (!defaultValue.empty() && !option.isDefaultValueHidden) {
+        out << " [" << defaultValue << ']';
+    }
 
     return out.str();
 }
 
 std::string InterfaceHelpPrinter::OptionGroup(const OptionGroupData& group)
 {
-    if (group.options.empty()) return {};
+    if (group.options.empty()) {
+        return {};
+    }
 
     std::ostringstream out;
-    if (!group.name.empty()) out << group.name << ":\n";
+    if (!group.name.empty()) {
+        out << group.name << ":\n";
+    }
 
     for (const OptionData& option : group.options) {
-        if (!option.isHidden) out << Option(option) << '\n';
+        if (!option.isHidden || showHiddenOptions_) {
+            out << Option(option) << '\n';
+        }
     }
     return out.str();
 }
@@ -176,18 +221,33 @@ std::string InterfaceHelpPrinter::Options()
     // print client option groups
     std::ostringstream out;
     const auto& optionGroups = interface_.OptionGroups();
-    for (const auto& optionGroup : optionGroups)
+    for (const auto& optionGroup : optionGroups) {
         out << OptionGroup(optionGroup) << '\n';
+    }
 
     // print builtin group
     OptionGroupData group;
-    if (optionGroups.empty()) group.name = "Options";
+    if (optionGroups.empty()) {
+        group.name = "Options";
+    }
     group.options.push_back(interface_.HelpOption());
     group.options.push_back(interface_.VersionOption());
-    if (interface_.NumThreadsOption()) group.options.push_back(interface_.NumThreadsOption().get());
-    if (interface_.LogLevelOption()) group.options.push_back(interface_.LogLevelOption().get());
-    if (interface_.LogFileOption()) group.options.push_back(interface_.LogFileOption().get());
-    if (interface_.VerboseOption()) group.options.push_back(interface_.VerboseOption().get());
+    group.options.push_back(interface_.AlarmsOption());
+    group.options.push_back(interface_.ExceptionsPassthroughOption());
+    group.options.push_back(interface_.ShowAllHelpOption());
+
+    if (interface_.NumThreadsOption()) {
+        group.options.push_back(*interface_.NumThreadsOption());
+    }
+    if (interface_.LogLevelOption()) {
+        group.options.push_back(*interface_.LogLevelOption());
+    }
+    if (interface_.LogFileOption()) {
+        group.options.push_back(*interface_.LogFileOption());
+    }
+    if (interface_.VerboseOption()) {
+        group.options.push_back(*interface_.VerboseOption());
+    }
     out << OptionGroup(group);
     return out.str();
 }
@@ -202,11 +262,14 @@ std::string InterfaceHelpPrinter::PositionalArgument(const PositionalArgumentDat
 std::string InterfaceHelpPrinter::PositionalArguments()
 {
     const auto& posArgs = interface_.PositionalArguments();
-    if (posArgs.empty()) return {};
+    if (posArgs.empty()) {
+        return {};
+    }
 
     std::ostringstream out;
-    for (const auto& posArg : posArgs)
+    for (const auto& posArg : posArgs) {
         out << PositionalArgument(posArg) << '\n';
+    }
 
     return out.str();
 }
@@ -216,16 +279,18 @@ void InterfaceHelpPrinter::Print(std::ostream& out) const { out << text_; }
 bool InterfaceHelpPrinter::ShouldShowDefaultValue(const OptionData& option)
 {
     // omit if switch OR null
-    if (option.type == OptionValueType::BOOL) return false;
+    if (option.type == OptionValueType::BOOL) {
+        return false;
+    }
 
     // omit if string-type option has an empty default
     if (option.type == OptionValueType::STRING) {
-        const auto& defaultValue = OptionValueToString(option.defaultValue.get());
+        const auto& defaultValue = OptionValueToString(*option.defaultValue);
         return !defaultValue.empty();
     }
 
     // otherwise (maybe) use default value
-    return option.defaultValue.is_initialized();
+    return bool{option.defaultValue};
 }
 
 std::string InterfaceHelpPrinter::Usage()
@@ -237,10 +302,14 @@ std::string InterfaceHelpPrinter::Usage()
 
     // print all required pos args & then optional ones after, regardless of order added
     for (const auto& posArg : interface_.PositionalArguments()) {
-        if (posArg.required) usage << " <" << posArg.name << '>';
+        if (posArg.required) {
+            usage << " <" << posArg.name << '>';
+        }
     }
     for (const auto& posArg : interface_.PositionalArguments()) {
-        if (!posArg.required) usage << " [" << posArg.name << ']';
+        if (!posArg.required) {
+            usage << " [" << posArg.name << ']';
+        }
     }
 
     return usage.str();
