@@ -1,25 +1,32 @@
 #include <pbcopper/cli2/internal/MultiToolInterfaceHelpPrinter.h>
 
+#include <pbcopper/cli2/internal/OptionData.h>
+#include "PbBoilerplateDisclaimer.h"
+
 #include <iomanip>
 #include <ios>
 #include <ostream>
 #include <sstream>
 
-#include <pbcopper/cli2/internal/OptionData.h>
-
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
 
-MultiToolInterfaceHelpPrinter::MultiToolInterfaceHelpPrinter(MultiToolInterface multiToolInterface)
-    : metrics_{multiToolInterface}, interface_{std::move(multiToolInterface)}
+MultiToolInterfaceHelpPrinter::MultiToolInterfaceHelpPrinter(MultiToolInterface multiToolInterface,
+                                                             HiddenOptionMode hiddenOptionMode)
+    : metrics_{multiToolInterface, hiddenOptionMode}
+    , interface_{std::move(multiToolInterface)}
+    , showHiddenOptions_{hiddenOptionMode == HiddenOptionMode::SHOW}
 {
     MakeHelpText();
 }
 
 MultiToolInterfaceHelpPrinter::MultiToolInterfaceHelpPrinter(MultiToolInterface multiToolInterface,
-                                                             const size_t maxColumn)
-    : metrics_{multiToolInterface, maxColumn}, interface_{std::move(multiToolInterface)}
+                                                             const size_t maxColumn,
+                                                             HiddenOptionMode hiddenOptionMode)
+    : metrics_{multiToolInterface, maxColumn, hiddenOptionMode}
+    , interface_{std::move(multiToolInterface)}
+    , showHiddenOptions_{hiddenOptionMode == HiddenOptionMode::SHOW}
 {
     MakeHelpText();
 }
@@ -30,7 +37,9 @@ void MultiToolInterfaceHelpPrinter::MakeHelpText()
     result << interface_.ApplicationName();
 
     const std::string description = interface_.ApplicationDescription();
-    if (!description.empty()) result << " - " << description;
+    if (!description.empty()) {
+        result << " - " << description;
+    }
     result << '\n';
 
     result << '\n'
@@ -46,18 +55,24 @@ void MultiToolInterfaceHelpPrinter::MakeHelpText()
 
     const auto& tools = interface_.Tools();
     for (const auto& tool : tools) {
-        if (tool.visibility == ToolVisibility::HIDDEN) continue;
+        if ((tool.visibility == ToolVisibility::HIDDEN) && !showHiddenOptions_) {
+            continue;
+        }
         const auto& i = tool.interface;
         result << "  " << std::setw(10) << std::left << tool.name << " "
                << i.ApplicationDescription() << '\n';
-        if (!tool.interface.Example().empty()) hasExamples = true;
+        if (!tool.interface.Example().empty()) {
+            hasExamples = true;
+        }
     }
     result << '\n';
 
     if (hasExamples) {
         result << "Examples:\n";
         for (const auto& tool : tools) {
-            if (tool.visibility == ToolVisibility::HIDDEN) continue;
+            if (tool.visibility == ToolVisibility::HIDDEN) {
+                continue;
+            }
             const auto& example = tool.interface.Example();
             if (!example.empty()) {
                 result << "  " << example << '\n';
@@ -67,7 +82,17 @@ void MultiToolInterfaceHelpPrinter::MakeHelpText()
     }
 
     const auto& footer = interface_.HelpFooter();
-    if (!footer.empty()) result << footer << '\n';
+    if (!footer.empty()) {
+        result << footer << '\n';
+
+        // Some application footers contain trailing newlines, some do not.
+        // Ensure we have at least one empty line between footer and disclaimer.
+        if (footer.back() != '\n') {
+            result << '\n';
+        }
+    }
+
+    result << PB_BOILERPLATE_DISCLAIMER;
 
     text_ = result.str();
 }
