@@ -1,8 +1,10 @@
 #include <pbcopper/dagcon/AlignmentGraph.h>
 
-#include <cassert>
-#include <cfloat>
-#include <cstdint>
+#include <pbcopper/dagcon/Alignment.h>
+#include <pbcopper/utility/Ssize.h>
+
+#include <boost/range/iterator_range.hpp>
+#include <boost/utility/value_init.hpp>
 
 #include <algorithm>
 #include <map>
@@ -10,11 +12,9 @@
 #include <string>
 #include <vector>
 
-#include <boost/range/iterator_range.hpp>
-#include <boost/utility/value_init.hpp>
-
-#include <pbcopper/dagcon/Alignment.h>
-#include <pbcopper/utility/Ssize.h>
+#include <cassert>
+#include <cfloat>
+#include <cstdint>
 
 namespace PacBio {
 namespace Dagcon {
@@ -23,8 +23,9 @@ AlignmentGraph::AlignmentGraph(const std::string& backbone) : backboneLength_{ba
 {
     // initialize the graph structure with the backbone length + enter/exit vertex
     graph_ = GraphType{backboneLength_ + 2};
-    for (size_t i = 0; i < backboneLength_ + 1; ++i)
+    for (size_t i = 0; i < backboneLength_ + 1; ++i) {
         boost::add_edge(i, i + 1, graph_);
+    }
 
     VertexIterator curr;
     VertexIterator last;
@@ -121,7 +122,7 @@ void AlignmentGraph::AddEdge(VertexIndex u, VertexIndex v)
     // otherwise add a new edge.
     bool edgeExists = false;
 
-    for (const auto& e : boost::make_iterator_range(boost::in_edges(v, graph_))) {
+    for (const auto e : boost::make_iterator_range(boost::in_edges(v, graph_))) {
         if (boost::source(e, graph_) == u) {
             // increment edge count
             graph_[e].Count++;
@@ -141,25 +142,31 @@ void AlignmentGraph::MergeNodes()
     seedNodes.push(enterVertex_);
 
     while (true) {
-        if (seedNodes.empty()) break;
+        if (seedNodes.empty()) {
+            break;
+        }
 
         const VertexIndex u = seedNodes.front();
         seedNodes.pop();
         MergeInNodes(u);
         MergeOutNodes(u);
 
-        for (const auto& e : boost::make_iterator_range(boost::out_edges(u, graph_))) {
+        for (const auto e : boost::make_iterator_range(boost::out_edges(u, graph_))) {
             graph_[e].Visited = true;
 
             int notVisited = 0;
             const VertexIndex v = boost::target(e, graph_);
-            for (const auto& inEdge : boost::make_iterator_range(boost::in_edges(v, graph_))) {
-                if (graph_[inEdge].Visited == false) ++notVisited;
+            for (const auto inEdge : boost::make_iterator_range(boost::in_edges(v, graph_))) {
+                if (graph_[inEdge].Visited == false) {
+                    ++notVisited;
+                }
             }
 
             // move onto the boost::target node after we visit all incoming edges for
             // the boost::target node
-            if (notVisited == 0) seedNodes.push(v);
+            if (notVisited == 0) {
+                seedNodes.push(v);
+            }
         }
     }
 }
@@ -168,7 +175,7 @@ void AlignmentGraph::MergeInNodes(VertexIndex n)
 {
     std::map<char, std::vector<VertexIndex>> nodeGroups;
 
-    for (const auto& inEdge : boost::make_iterator_range(boost::in_edges(n, graph_))) {
+    for (const auto inEdge : boost::make_iterator_range(boost::in_edges(n, graph_))) {
         const VertexIndex inNode = boost::source(inEdge, graph_);
         if (out_degree(inNode, graph_) == 1) {
             nodeGroups[graph_[inNode].Base].push_back(inNode);
@@ -178,7 +185,9 @@ void AlignmentGraph::MergeInNodes(VertexIndex n)
     // iterate over node groups, merge an accumulate information
     for (const auto& kvp : nodeGroups) {
         const auto& nodes = kvp.second;
-        if (nodes.size() <= 1) continue;
+        if (nodes.size() <= 1) {
+            continue;
+        }
 
         auto ni = nodes.cbegin();
         const VertexIndex an = *ni++;
@@ -206,7 +215,7 @@ void AlignmentGraph::MergeInNodes(VertexIndex n)
         ++ni;
         for (; ni != nodes.cend(); ++ni) {
             const VertexIndex vtx = *ni;
-            for (const auto& newEdge : boost::make_iterator_range(boost::in_edges(vtx, graph_))) {
+            for (const auto newEdge : boost::make_iterator_range(boost::in_edges(vtx, graph_))) {
                 const VertexIndex n1 = boost::source(newEdge, graph_);
 
                 EdgeIndex e;
@@ -236,7 +245,7 @@ void AlignmentGraph::MergeOutNodes(VertexIndex n)
 {
     std::map<char, std::vector<VertexIndex>> nodeGroups;
 
-    for (const auto& outEdge : boost::make_iterator_range(boost::out_edges(n, graph_))) {
+    for (const auto outEdge : boost::make_iterator_range(boost::out_edges(n, graph_))) {
         const VertexIndex outNode = boost::target(outEdge, graph_);
         if (in_degree(outNode, graph_) == 1) {
             nodeGroups[graph_[outNode].Base].push_back(outNode);
@@ -245,7 +254,9 @@ void AlignmentGraph::MergeOutNodes(VertexIndex n)
 
     for (const auto& kvp : nodeGroups) {
         const auto& nodes = kvp.second;
-        if (nodes.size() <= 1) continue;
+        if (nodes.size() <= 1) {
+            continue;
+        }
 
         auto nodeIter = nodes.cbegin();
         const VertexIndex an = *nodeIter;
@@ -268,7 +279,7 @@ void AlignmentGraph::MergeOutNodes(VertexIndex n)
         ++nodeIter;
         for (; nodeIter != nodes.cend(); ++nodeIter) {
             VertexIndex vtx = *nodeIter;
-            for (const auto& newEdge : boost::make_iterator_range(boost::out_edges(vtx, graph_))) {
+            for (const auto newEdge : boost::make_iterator_range(boost::out_edges(vtx, graph_))) {
                 const VertexIndex n2 = boost::target(newEdge, graph_);
 
                 EdgeIndex e;
@@ -440,7 +451,9 @@ void AlignmentGraph::ConsensusWithMinFlankCoverage(std::vector<ConsensusResult>&
     auto curr = startNode;
     for (; curr != endNode; ++curr) {
         const AlignmentNode& n = *curr;
-        if (n.Base == graph_[enterVertex_].Base || n.Base == graph_[exitVertex_].Base) continue;
+        if (n.Base == graph_[enterVertex_].Base || n.Base == graph_[exitVertex_].Base) {
+            continue;
+        }
 
         cns += n.Base;
 
@@ -469,7 +482,7 @@ void AlignmentGraph::ConsensusWithMinFlankCoverage(std::vector<ConsensusResult>&
 
 std::vector<AlignmentNode> AlignmentGraph::BestPath()
 {
-    for (const auto& edge : boost::make_iterator_range(edges(graph_))) {
+    for (const auto edge : boost::make_iterator_range(edges(graph_))) {
         graph_[edge].Visited = false;
     }
 
@@ -482,7 +495,9 @@ std::vector<AlignmentNode> AlignmentGraph::BestPath()
     nodeScore[exitVertex_] = 0.0f;
 
     while (true) {
-        if (seedNodes.empty()) break;
+        if (seedNodes.empty()) {
+            break;
+        }
 
         const VertexIndex n = seedNodes.front();
         seedNodes.pop();
@@ -491,7 +506,7 @@ std::vector<AlignmentNode> AlignmentGraph::BestPath()
         float bestScore = -FLT_MAX;
         EdgeIndex bestEdgeD = boost::initialized_value;
 
-        for (const auto& outEdgeD : boost::make_iterator_range(boost::out_edges(n, graph_))) {
+        for (const auto outEdgeD : boost::make_iterator_range(boost::out_edges(n, graph_))) {
             const VertexIndex outNodeD = boost::target(outEdgeD, graph_);
             const AlignmentNode& outNode = graph_[outNodeD];
 
@@ -516,19 +531,23 @@ std::vector<AlignmentNode> AlignmentGraph::BestPath()
             bestNodeScoreEdge[n] = bestEdgeD;
         }
 
-        for (const auto& inEdge : boost::make_iterator_range(boost::in_edges(n, graph_))) {
+        for (const auto inEdge : boost::make_iterator_range(boost::in_edges(n, graph_))) {
             graph_[inEdge].Visited = true;
             const VertexIndex inNode = boost::source(inEdge, graph_);
             int notVisited = 0;
 
-            for (const auto& newOutEdge :
+            for (const auto newOutEdge :
                  boost::make_iterator_range(boost::out_edges(inNode, graph_))) {
-                if (graph_[newOutEdge].Visited == false) notVisited++;
+                if (graph_[newOutEdge].Visited == false) {
+                    notVisited++;
+                }
             }
 
             // move onto the target node after we visit all incoming edges for
             // the target node
-            if (notVisited == 0) seedNodes.push(inNode);
+            if (notVisited == 0) {
+                seedNodes.push(inNode);
+            }
         }
     }
 
@@ -554,8 +573,10 @@ std::vector<AlignmentNode> AlignmentGraph::BestPath()
 
 bool AlignmentGraph::DanglingNodes()
 {
-    for (const auto& vertex : boost::make_iterator_range(boost::vertices(graph_))) {
-        if (graph_[vertex].Deleted) continue;
+    for (const auto vertex : boost::make_iterator_range(boost::vertices(graph_))) {
+        if (graph_[vertex].Deleted) {
+            continue;
+        }
         if (graph_[vertex].Base == graph_[enterVertex_].Base ||
             graph_[vertex].Base == graph_[exitVertex_].Base) {
             continue;
@@ -563,7 +584,9 @@ bool AlignmentGraph::DanglingNodes()
 
         const int indeg = out_degree(vertex, graph_);
         const int outdeg = in_degree(vertex, graph_);
-        if (outdeg > 0 && indeg > 0) continue;
+        if (outdeg > 0 && indeg > 0) {
+            continue;
+        }
 
         return true;
     }
