@@ -1,13 +1,11 @@
-// Author: Lance Hepler
-
 #include <pbcopper/data/ReadId.h>
 
+#include <pbcopper/data/ReadName.h>
+
 #include <ostream>
 #include <sstream>
 #include <string>
 
-#include <pbcopper/data/ReadName.h>
-
 namespace PacBio {
 namespace Data {
 
@@ -17,12 +15,14 @@ ReadId::ReadId(const std::string& readName) : ReadName{readName}
         Data::ReadName rName{readName};
         MovieName = rName.MovieName().ToStdString();
         HoleNumber = static_cast<size_t>(rName.Zmw());
-        if (!rName.IsCCS()) ZmwInterval = rName.QueryInterval();
+        if (!rName.IsCCS()) {
+            ZmwInterval = rName.QueryInterval();
+        }
     }
 }
 
 ReadId::ReadId(const std::string& movieName, size_t holeNumber)
-    : MovieName{movieName}, HoleNumber{holeNumber}, ZmwInterval{boost::none}
+    : MovieName{movieName}, HoleNumber{holeNumber}
 {
 }
 
