@@ -1,5 +1,3 @@
-// Authors: Chris Dunn, Zev Kronenberg, Derek Barnett
-
 #include <pbcopper/pbmer/DbgNode.h>
 
 #include <array>
@@ -50,7 +48,9 @@ bool DbgNode::AddLoad(uint32_t rid)
 }
 size_t DbgNode::FirstRId() const
 {
-    if (readIds2_.none()) return 0;
+    if (readIds2_.none()) {
+        return 0;
+    }
     return readIds2_.find_first() + 1;
 }
 
