@@ -1,14 +1,13 @@
-// Authors: Chris Dunn, Zev Kronenberg, Derek Barnett
 #include <pbcopper/pbmer/Parser.h>
 
-#include <cassert>
-
 #include <algorithm>
 #include <array>
 #include <limits>
 #include <stdexcept>
 #include <vector>
 
+#include <cassert>
+
 namespace PacBio {
 namespace Pbmer {
 
@@ -24,8 +23,9 @@ Parser::Parser(uint8_t kmerSize)
 
 Mers Parser::Parse(const std::string& dna) const
 {
-    if (dna.size() < kmerSize_)
+    if (dna.size() < kmerSize_) {
         throw std::runtime_error{"[pbmer] parsing ERROR: DNA sequence shorter than kmer size."};
+    }
 
     Mers kms{kmerSize_};
     Kmer forwardKmer{Data::Strand::FORWARD};
@@ -37,9 +37,6 @@ Mers Parser::Parse(const std::string& dna) const
     // The length of the current kmer buffer, lk needs to be >= to kmer_size
     // before a kmer is complete. Remember the kmer is build in a sliding fashion
     int lk = 0;
-    // The count of the number of kmers/2. Unknown bases are skipped so the
-    // dna.size() != size( kmers )
-    int n = 0;
 
     for (const auto d : dna) {
         // check that only ASCII is used
@@ -62,7 +59,6 @@ Mers Parser::Parse(const std::string& dna) const
             reverseKmer.pos += kmerSize_;
         }
         if (lk >= kmerSize_) {
-            n += 2;
             kms.AddKmer(forwardKmer);
             kms.AddKmer(reverseKmer);
             ++forwardKmer.pos;
@@ -76,8 +72,9 @@ Mers Parser::Parse(const std::string& dna) const
 
 std::vector<DnaBit> Parser::ParseDnaBit(const std::string& dna) const
 {
-    if (dna.size() < kmerSize_)
+    if (dna.size() < kmerSize_) {
         throw std::runtime_error{"[pbmer] parsing ERROR: DNA sequence shorter than kmer size."};
+    }
 
     std::vector<DnaBit> kms;
     kms.reserve(dna.size() - kmerSize_ + 1);
@@ -91,9 +88,6 @@ std::vector<DnaBit> Parser::ParseDnaBit(const std::string& dna) const
     // The length of the current kmer buffer, lk needs to be >= to kmer_size
     // before a kmer is complete. Remember the kmer is build in a sliding fashion
     int lk = 0;
-    // The count of the number of kmers/2. Unknown bases are skipped so the
-    // dna.size() != size( kmers )
-    int n = 0;
 
     for (const auto d : dna) {
         // check that only ASCII is used
@@ -112,7 +106,6 @@ std::vector<DnaBit> Parser::ParseDnaBit(const std::string& dna) const
             forwardKmer.mer = 0;
         }
         if (lk >= kmerSize_) {
-            n += 2;
             kms.emplace_back(forwardKmer);
         }
         ++i;
@@ -123,8 +116,9 @@ std::vector<DnaBit> Parser::ParseDnaBit(const std::string& dna) const
 
 void Parser::ParseDnaBit(const std::string& dna, std::vector<DnaBit>& kms) const
 {
-    if (dna.size() < kmerSize_)
+    if (dna.size() < kmerSize_) {
         throw std::runtime_error{"[pbmer] parsing ERROR: DNA sequence shorter than kmer size."};
+    }
 
     DnaBit forwardKmer;
     forwardKmer.strand = 0;
@@ -136,9 +130,6 @@ void Parser::ParseDnaBit(const std::string& dna, std::vector<DnaBit>& kms) const
     // The length of the current kmer buffer, lk needs to be >= to kmer_size
     // before a kmer is complete. Remember the kmer is build in a sliding fashion
     int lk = 0;
-    // The count of the number of kmers/2. Unknown bases are skipped so the
-    // dna.size() != size( kmers )
-    int n = 0;
 
     for (const auto d : dna) {
         // check that only ASCII is used
@@ -157,7 +148,6 @@ void Parser::ParseDnaBit(const std::string& dna, std::vector<DnaBit>& kms) const
             forwardKmer.mer = 0;
         }
         if (lk >= kmerSize_) {
-            n += 2;
             kms.emplace_back(forwardKmer);
         }
         ++i;
@@ -185,7 +175,9 @@ void Parser::RLE(std::string& dna) const
 {
     auto first = dna.begin();
     auto last = dna.end();
-    if (first == last) return;
+    if (first == last) {
+        return;
+    }
     auto result = first;
     while (++first != last) {
         if (!(*result == *first) && ++result != first) {
