@@ -17,7 +17,9 @@ TaskReport::TaskReport(int nproc, double runTime, int exitCode, int64_t peakRss)
 #if defined(_POSIX_VERSION)
     char hostname_[255];
     int rc = gethostname(hostname_, 255);
-    if (rc != 0) throw std::runtime_error{"[pbcopper] reports ERROR: gethostname() failed"};
+    if (rc != 0) {
+        throw std::runtime_error{"[pbcopper] reports ERROR: gethostname() failed"};
+    }
     std::string hostname(hostname_);
 #else
     std::string hostname = "unknown";
