@@ -12,10 +12,10 @@
 #include <pbcopper/cli2/PositionalArgument.h>
 #include <pbcopper/cli2/Results.h>
 #include <pbcopper/cli2/internal/HelpMetrics.h>
-#include <pbcopper/cli2/internal/InterfaceHelpPrinter.h>
-#include <pbcopper/cli2/internal/MultiToolInterfaceHelpPrinter.h>
+#include <pbcopper/utility/Alarm.h>
 #include <pbcopper/utility/OStreamRedirect.h>
 
+#include "../../../src/cli2/PbBoilerplateDisclaimer.h"
 #include "PbcopperTestData.h"
 
 // clang-format off
@@ -154,6 +154,7 @@ TEST(CLI2_CLI, can_print_help)
 "                          WARN, FATAL). [WARN]\n"
 "  --log-file        FILE  Log to a file, instead of stderr.\n"
 "\n"
+PB_BOILERPLATE_DISCLAIMER
 };
 
     const std::vector<std::string> args {
@@ -219,7 +220,10 @@ Typical workflow:
 
   5. Polish transcripts using subreads
      $ isoseq3 polish unpolished.bam movie.subreads.bam polished.bam
-)"};
+
+)"
+PB_BOILERPLATE_DISCLAIMER
+};
 
     PacBio::CLI_v2::MultiToolInterface i{"isoseq3", "De Novo Transcript Reconstruction", "3.1.2"};
     i.AddTools({{"refine",    CLI_v2_CLITests::MakeRefineInterface(),    &CLI_v2_CLITests::RefineRunner},
@@ -246,7 +250,8 @@ Typical workflow:
      $ isoseq3 cluster movie.flnc.bam unpolished.bam --verbose
 
   5. Polish transcripts using subreads
-     $ isoseq3 polish unpolished.bam movie.subreads.bam polished.bam)");
+     $ isoseq3 polish unpolished.bam movie.subreads.bam polished.bam
+)");
 
     const std::vector<std::string> args {
         "isoseq3", "-h"
@@ -281,7 +286,9 @@ Usage:
                           WARN, FATAL). [WARN]
   --log-file        FILE  Log to a file, instead of stderr.
 
-)"};
+)"
+PB_BOILERPLATE_DISCLAIMER
+};
 
     PacBio::CLI_v2::MultiToolInterface i{"isoseq3", "De Novo Transcript Reconstruction", "3.1.2"};
     i.AddTools({{"refine",    CLI_v2_CLITests::MakeRefineInterface(),    &CLI_v2_CLITests::RefineRunner},
@@ -778,7 +785,82 @@ TEST(CLI2_CLI, creates_alarm_for_all_exceptions_when_given_alarm_file_arg) {
     EXPECT_TRUE(alarmText.str().find("std exception from application") != std::string::npos);
 }
 
-TEST(CLI2_CLI, multitoolinterface_supports_hidden_subtools)
+TEST(CLI2_CLI, populates_alarm_owner_field_with_application_name) {
+
+    const std::string alarmFilename{PacBio::PbcopperTestsConfig::Generated_Dir + "/add_owner_alarm.json"};
+    const std::vector<std::string> args {"owner-check", "--alarms", alarmFilename};
+    auto runner = [](const PacBio::CLI_v2::Results&)
+    {
+        throw PB_ALARM("alarm type", "alarm message");
+        return 0;
+    };
+
+    std::ostringstream logOutput;
+    PacBio::Utility::CerrRedirect redirect{logOutput.rdbuf()};
+    std::ignore = redirect;
+
+    PacBio::CLI_v2::Interface i{"owner-check", "Check owner in alarm.", "v3.1"};
+    const int result = PacBio::CLI_v2::Run(args, i, runner);
+    EXPECT_EQ(EXIT_FAILURE, result);
+
+    // check alarm file
+    std::ifstream alarmFile{alarmFilename};
+    std::ostringstream alarmText;
+    alarmText << alarmFile.rdbuf();
+    EXPECT_TRUE(alarmText.str().find("\"owner\": \"owner-check\"") != std::string::npos);
+    EXPECT_TRUE(alarmText.str().find("\"message\": \"alarm message\"") != std::string::npos);
+    EXPECT_TRUE(alarmText.str().find("\"name\": \"alarm type\"") != std::string::npos);
+}
+
+TEST(CLI2_CLI, show_all_help_displays_hidden_options)
+{
+    using namespace PacBio;
+
+    const CLI_v2::Option HiddenOption
+{
+R"({
+    "names" : ["hidden-mode"],
+    "description" : "Hidden mode",
+    "type" : "string",
+    "hidden" : true
+})"
+};
+
+    const auto runner = [](const CLI_v2::Results&) { return EXIT_SUCCESS; };
+
+    CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
+    i.AddOption(HiddenOption);
+
+    // --all-help
+    {
+        const std::vector<std::string> args {
+            "frobber", "--all-help"
+        };
+
+        std::ostringstream s;
+        Utility::CoutRedirect redirect{s.rdbuf()};
+        std::ignore = redirect;
+        const int result = CLI_v2::Run(args, i, runner);
+        EXPECT_EQ(EXIT_SUCCESS, result);
+        EXPECT_NE(std::string::npos, s.str().find("--hidden-mode"));
+    }
+
+    // --show-all-help
+    {
+        const std::vector<std::string> args {
+            "frobber", "--show-all-help"
+        };
+
+        std::ostringstream s;
+        Utility::CoutRedirect redirect{s.rdbuf()};
+        std::ignore = redirect;
+        const int result = CLI_v2::Run(args, i, runner);
+        EXPECT_EQ(EXIT_SUCCESS, result);
+        EXPECT_NE(std::string::npos, s.str().find("--hidden-mode"));
+    }
+}
+
+TEST(CLI2_CLI, show_all_help_displays_hidden_subtools)
 {
     using namespace PacBio;
 
@@ -788,26 +870,33 @@ TEST(CLI2_CLI, multitoolinterface_supports_hidden_subtools)
                 {"polish",    CLI_v2_CLITests::MakePolishInterface(),    &CLI_v2_CLITests::PolishRunner},
                 {"summarize", CLI_v2_CLITests::MakeSummarizeInterface(), &CLI_v2_CLITests::SummarizeRunner}});
 
-    // hidden from help
-    {
-        CLI_v2::internal::MultiToolInterfaceHelpPrinter help{i};
-        std::ostringstream out;
-        help.Print(out);
-        EXPECT_TRUE(out.str().find("refine") == std::string::npos);
-    }
-
-    // can run from CLI
+    // --all-help
     {
         const std::vector<std::string> args {
-        "isoseq3", "refine", "--test", "--count", "10"
+            "isoseq3", "--all-help"
         };
 
         std::ostringstream s;
         Utility::CoutRedirect redirect{s.rdbuf()};
         std::ignore = redirect;
-
         const int result = CLI_v2::Run(args, i);
         EXPECT_EQ(EXIT_SUCCESS, result);
+        EXPECT_NE(std::string::npos, s.str().find("refine"));
+    }
+
+    
+    // --show-all-help
+    {
+        const std::vector<std::string> args {
+            "isoseq3", "--show-all-help"
+        };
+
+        std::ostringstream s;
+        Utility::CoutRedirect redirect{s.rdbuf()};
+        std::ignore = redirect;
+        const int result = CLI_v2::Run(args, i);
+        EXPECT_EQ(EXIT_SUCCESS, result);
+        EXPECT_NE(std::string::npos, s.str().find("refine"));
     }
 }
 
