@@ -12,6 +12,9 @@
 #include <pbcopper/cli2/internal/OptionTranslator.h>
 #include <pbcopper/cli2/internal/PositionalArgumentTranslator.h>
 
+#include "../../../src/cli2/PbBoilerplateDisclaimer.h"
+
+using HiddenOptionMode = PacBio::CLI_v2::internal::HiddenOptionMode;
 using Interface = PacBio::CLI_v2::Interface;
 using InterfaceHelpPrinter = PacBio::CLI_v2::internal::InterfaceHelpPrinter;
 using MultiToolInterface = PacBio::CLI_v2::MultiToolInterface;
@@ -110,6 +113,17 @@ R"({
 })"
 };
 
+const Option Seed
+{
+R"({
+    "names" : ["seed"],
+    "description" : "Seed for random-number generator.",
+    "type" : "int",
+    "default" : -1,
+    "default.hidden" : true
+})"
+};
+
 const PositionalArgument Source
 {
 R"({
@@ -147,7 +161,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_usage)
 
     const Interface i{"frobber"};
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto formattedText = help.Usage();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -163,7 +177,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_usage_with_pos_args)
         CLI_v2_InterfaceHelpPrinterTests::Options::OptionalStats
     });
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto formattedText = help.Usage();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -179,7 +193,7 @@ TEST(CLI2_InterfaceHelpPrinter, usage_with_optional_pos_args_always_places_them_
         CLI_v2_InterfaceHelpPrinterTests::Options::Dest
     });
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto formattedText = help.Usage();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -190,7 +204,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_description)
 
     Interface i{"frobber", "some description"};
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto formattedText = help.Description();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -201,7 +215,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_empty_description)
 
     Interface i{"frobber", ""};
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto formattedText = help.Description();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -218,7 +232,7 @@ TEST(CLI2_InterfaceHelpPrinter, no_formatted_option_names_for_hidden_option)
 TEST(CLI2_InterfaceHelpPrinter, can_calculate_metrics_from_builtins_only)
 {
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
 
     const auto& metrics = help.Metrics();
 
@@ -245,13 +259,13 @@ TEST(CLI2_InterfaceHelpPrinter, can_calculate_metrics_with_long_option)
     Interface i{"frobber"};
     i.AddOption(testOption);
 
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto& metrics = help.Metrics();
     EXPECT_EQ(longestText.size(), metrics.maxNameLength);  // include spacer
 
     const auto testOptionData = OptionTranslator::Translate(testOption);
     const auto& helpOption = i.HelpOption();
-    const auto& logLevelOption = i.LogLevelOption().get();
+    const auto& logLevelOption = *i.LogLevelOption();
     const auto& versionOption = i.VersionOption();
     EXPECT_EQ(longestText,  metrics.formattedOptionNames.at(testOptionData).nameString);
     EXPECT_EQ(helpText,     metrics.formattedOptionNames.at(helpOption).nameString);
@@ -273,7 +287,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_int_choices)
     option.choices = {choice1, choice2, choice3, choice4};
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
 
     const auto formattedText = help.Choices(option);
     EXPECT_EQ(expectedText, formattedText);
@@ -293,7 +307,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_float_choices)
     option.choices = {choice1, choice2, choice3, choice4};
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
 
     const auto formattedText = help.Choices(option);
     EXPECT_EQ(expectedText, formattedText);
@@ -313,7 +327,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_string_choices)
     option.choices = {choice1, choice2, choice3, choice4};
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
 
     const auto formattedText = help.Choices(option);
     EXPECT_EQ(expectedText, formattedText);
@@ -323,7 +337,7 @@ TEST(CLI2_InterfaceHelpPrinter, should_not_show_default_value_for_boolean)
 {
     OptionData option;
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     EXPECT_FALSE(help.ShouldShowDefaultValue(option));
 }
 
@@ -333,7 +347,7 @@ TEST(CLI2_InterfaceHelpPrinter, should_not_show_default_value_for_empty_string)
     option.type = OptionValueType::STRING;
     option.defaultValue = std::string{};
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     EXPECT_FALSE(help.ShouldShowDefaultValue(option));
 }
 
@@ -343,7 +357,7 @@ TEST(CLI2_InterfaceHelpPrinter, should_show_default_value_for_string)
     option.type = OptionValueType::STRING;
     option.defaultValue = std::string{"foo"};
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     EXPECT_TRUE(help.ShouldShowDefaultValue(option));
 }
 
@@ -353,7 +367,7 @@ TEST(CLI2_InterfaceHelpPrinter, should_show_default_value_for_number)
     option.type = OptionValueType::INT;
     option.defaultValue = 42;
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     EXPECT_TRUE(help.ShouldShowDefaultValue(option));
 }
 
@@ -362,7 +376,7 @@ TEST(CLI2_InterfaceHelpPrinter, should_not_show_default_value_for_number_with_no
     OptionData option;
     option.type = OptionValueType::INT;
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     EXPECT_FALSE(help.ShouldShowDefaultValue(option));
 }
 
@@ -375,7 +389,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_default_value)
     const std::string expectedText{"42"};
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i};
+    InterfaceHelpPrinter help{i, HiddenOptionMode::HIDE};
     const auto defaultValue = help.DefaultValue(option);
     EXPECT_EQ(expectedText, defaultValue);
 }
@@ -402,7 +416,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_option_with_wordwrapped_description)
     Interface i{"frobber"};
     i.AddOption(optionWithLongDescription);
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.Option(option);
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -412,7 +426,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_empty_option_group)
     const std::string expectedText;
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.OptionGroup(OptionGroupData{});
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -429,7 +443,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_builtin_option_group)
         "  --log-file        FILE  Log to a file, instead of stderr.\n"};
 
     Interface i{"frobber"};
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.Options();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -447,7 +461,7 @@ TEST(CLI2_InterfaceHelpPrinter, prints_log_level_override)
 
     Interface i{"frobber"};
     i.DefaultLogLevel(PacBio::Logging::LogLevel::DEBUG);
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.Options();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -476,7 +490,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_option_group)
 
     Interface i{"frobber"};
     i.AddOptionGroup("Test Group", options);
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.OptionGroup({"Test Group", optionsData});
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -495,7 +509,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_positional_argument)
 
     const auto posArgData = PositionalArgumentTranslator::Translate(CLI_v2_InterfaceHelpPrinterTests::Options::Source);
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.PositionalArgument(posArgData);
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -522,7 +536,7 @@ TEST(CLI2_InterfaceHelpPrinter, formats_positional_argument_with_wordwrapped_des
 
     const auto posArgData = PositionalArgumentTranslator::Translate(CLI_v2_InterfaceHelpPrinterTests::Options::Source);
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.PositionalArguments();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -547,6 +561,7 @@ Output Options:
   -n,--no-op               Dry run. Report actions that would be taken but do
                            not perform them.
   --timeout         INT    Abort execution after <INT> milliseconds. [5000]
+  --seed            INT    Seed for random-number generator.
 
 Algorithm Options:
   --delta           FLOAT  Some delta for things. [0.01]
@@ -562,7 +577,9 @@ Algorithm Options:
                            WARN, FATAL). [WARN]
   --log-file        FILE   Log to a file, instead of stderr.
 
-)"};
+)"
+PB_BOILERPLATE_DISCLAIMER
+};
 
     Interface i {
         "frobber",
@@ -575,7 +592,8 @@ Algorithm Options:
         CLI_v2_InterfaceHelpPrinterTests::Options::Force,
         CLI_v2_InterfaceHelpPrinterTests::Options::TargetDirectory,
         CLI_v2_InterfaceHelpPrinterTests::Options::DryRun,
-        CLI_v2_InterfaceHelpPrinterTests::Options::Timeout
+        CLI_v2_InterfaceHelpPrinterTests::Options::Timeout,
+        CLI_v2_InterfaceHelpPrinterTests::Options::Seed,
     });
     i.AddOptionGroup("Algorithm Options",{
         CLI_v2_InterfaceHelpPrinterTests::Options::Delta,
@@ -589,7 +607,7 @@ Algorithm Options:
         CLI_v2_InterfaceHelpPrinterTests::Options::OptionalStats
     });
 
-    const InterfaceHelpPrinter help{i, 80};
+    const InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     std::ostringstream out;
     help.Print(out);
     EXPECT_EQ(expectedText, out.str());
@@ -619,6 +637,7 @@ TEST(CLI2_InterfaceHelpPrinter, word_wraps_application_description)
 "                          WARN, FATAL). [WARN]\n"
 "  --log-file        FILE  Log to a file, instead of stderr.\n"
 "\n"
+PB_BOILERPLATE_DISCLAIMER
     };
 
     Interface i {
@@ -626,7 +645,7 @@ TEST(CLI2_InterfaceHelpPrinter, word_wraps_application_description)
         "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.",
         "3.14"
     };
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     std::ostringstream out;
     out << help;
     EXPECT_EQ(expectedText, out.str());
@@ -657,7 +676,10 @@ Typical workflow:
   3. Lather, rinse, repeat.
 
   So long, and thanks for all the fish.
-)"};
+
+)"
+PB_BOILERPLATE_DISCLAIMER
+};
 
     Interface i {
         "frobber",
@@ -675,7 +697,7 @@ Typical workflow:
 
   So long, and thanks for all the fish.)");
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     std::ostringstream out;
     out << help;
     EXPECT_EQ(expectedText, out.str());
@@ -693,7 +715,7 @@ TEST(CLI2_InterfaceHelpPrinter, can_disable_builtins)
      .DisableLogLevelOption()
      .DisableNumThreadsOption();
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.Options();
     EXPECT_EQ(expectedText, formattedText);
 }
@@ -713,9 +735,67 @@ TEST(CLI2_InterfaceHelpPrinter, can_enable_verbose_option)
     Interface i{"frobber"};
     i.EnableVerboseOption();
 
-    InterfaceHelpPrinter help{i, 80};
+    InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
     const auto formattedText = help.Options();
     EXPECT_EQ(expectedText, formattedText);
 }
 
+TEST(CLI2_InterfaceHelpPrinter, can_handle_hidden_options)
+{
+    const Option triforceOption {
+R"({
+    "names" : ["t", "triforce"],
+    "description" : "Choose wisely.",
+    "type" : "string",
+    "choices" : ["power", "wisdom", "courage"],
+    "choices.hidden" : true,
+    "default" : "power"
+})"};
+
+    const Option doomOption {
+R"({
+    "names" : ["iddqd"],
+    "description" : "You know.",
+    "hidden" : true
+})"};
+
+    const std::string hiddenAlarms{"--alarms"};
+    const std::string hiddenExceptionsPassthrough{"--allow-exceptions-passthrough"};
+    const std::string hiddenShowAllHelp{"--show-all-help"};
+    // stopping short for choice list text, in case of wrap-around
+    const std::string hiddenTriforceChoices{"Choose wisely. Valid choices: ("}; 
+    const std::string hiddenDoom{"--iddqd"};
+
+    Interface i{"frobber"};
+    i.AddOptionGroup("Test Group", {triforceOption, doomOption});
+
+    // ensure hidden
+    {
+        InterfaceHelpPrinter help{i, 80, HiddenOptionMode::HIDE};
+        std::ostringstream helpOutput;
+        help.Print(helpOutput);
+        const std::string helpText = helpOutput.str();
+
+        EXPECT_EQ(std::string::npos, helpText.find(hiddenAlarms));
+        EXPECT_EQ(std::string::npos, helpText.find(hiddenExceptionsPassthrough));
+        EXPECT_EQ(std::string::npos, helpText.find(hiddenShowAllHelp));
+        EXPECT_EQ(std::string::npos, helpText.find(hiddenTriforceChoices));
+        EXPECT_EQ(std::string::npos, helpText.find(hiddenDoom));
+    }
+
+    // expose via --show-all-help
+    {
+        InterfaceHelpPrinter help{i, 80, HiddenOptionMode::SHOW};
+        std::ostringstream helpOutput;
+        help.Print(helpOutput);
+        const std::string helpText = helpOutput.str();
+
+        EXPECT_NE(std::string::npos, helpText.find(hiddenAlarms));
+        EXPECT_NE(std::string::npos, helpText.find(hiddenExceptionsPassthrough));
+        EXPECT_NE(std::string::npos, helpText.find(hiddenShowAllHelp));
+        EXPECT_NE(std::string::npos, helpText.find(hiddenTriforceChoices));
+        EXPECT_NE(std::string::npos, helpText.find(hiddenDoom));
+    }
+}
+
 // clang-format on
