@@ -1,7 +1,6 @@
-// Author: Armin Töpfer
+#include <pbcopper/parallel/FireAndForget.h>
 
 #include <chrono>
-#include <iostream>
 #include <memory>
 #include <string>
 #include <thread>
@@ -9,8 +8,6 @@
 
 #include <gtest/gtest.h>
 
-#include <pbcopper/parallel/FireAndForget.h>
-
 TEST(Parallel_FireAndForget, strings)
 {
     static const size_t numThreads = 3;
@@ -37,8 +34,9 @@ TEST(Parallel_FireAndForget, strings)
     EXPECT_NO_THROW(faf.Finalize());
     EXPECT_EQ(waiting, 0);
 
-    for (auto& v : vec)
+    for (auto& v : vec) {
         EXPECT_EQ(v.substr(0, 4), "done");
+    }
 
     EXPECT_EQ(vec.size(), numElements);
 }
@@ -92,3 +90,30 @@ TEST(Parallel_FireAndForget, exceptionProduceWith)
 
     EXPECT_EQ(counter, 2);
 }
+
+TEST(Parallel_FireAndForget, dispatch)
+{
+    static const size_t numThreads = 3;
+    static const size_t numElements = 1000;
+    PacBio::Parallel::FireAndForget faf{numThreads};
+
+    std::vector<std::string> vec;
+    for (size_t i = 0; i < numElements; ++i) {
+        vec.emplace_back(std::to_string(i));
+    }
+
+    const auto Submit = [&vec](const int32_t i) {
+        std::string& input = vec[i];
+        input = "done-" + input;
+    };
+
+    PacBio::Parallel::Dispatch(&faf, numElements, Submit);
+
+    for (auto& v : vec) {
+        EXPECT_EQ(v.substr(0, 4), "done");
+    }
+
+    EXPECT_EQ(vec.size(), numElements);
+
+    faf.Finalize();
+}
